Pane

Please note Pane is not ready for development use. It is in early development.

Package Version Hex Docs

gleam add pane-gleam@1
import pane/window

pub fn main() -> Nil {
  // Put all of the things that are needed like input: "file/url path"
  // Route files from the priv/pane/ directory, that is where the binary will look for files.
  let Config = window.WindowConfig() // < --------
  let PreparedConfig: String = window.prepare_window(Config)
  window.load_window(PreparedConfig)

  
}

Further documentation can be found at https://pane_gleam.hexdocs.pm/.

Development

gleam run -m pane build
cd priv/pane/
./my-project
Search Document